

# Folder structure

Try to keep this folder very high level. And dont add more things here as the cognitive load score here is very high
already.

@Todo: Move scripts of the desktop to the desktop folder.
